Name:           boomaga
Version:        1.3.0
Release:        %mkrel 1
Summary:        A virtual printer for viewing a document before printing
Group:          System/Printing
License:        GPLv2 and LGPLv2+
Url:            http://boomaga.github.io/
Source0:        https://github.com/Boomaga/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  cups-devel
BuildRequires:  ghostscript-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(poppler-cpp)
BuildRequires:  pkgconfig(poppler)
BuildRequires:  snappy-devel

Requires(pre):  ghostscript
Requires:       snappy
Requires(preun):cups-common
Requires(post): paper-utils
Requires(pre):  task-printing-server


%description
Boomaga (BOOklet MAnager) is a virtual printer for viewing a document
before printing it out using the physical printer. The program is very
simple to work with. Running any program, click “print” and select
“Boomaga” to see in several seconds (CUPS takes some time to respond)
the Boomaga window open. If you print out one more document,
it gets added to the previous one, and you can also print them
out as one. Regardless of whether your printer supports duplex
printing or not, you would be able to easily print on both sides
of the sheet. If your printer does not support duplex printing,
point this out in the settings, and Booklet would ask you to turn
over the pages half way through printing your document.

The program can also help you get your documents prepared a bit
before printing. At this stage Boomaga makes it possible to:

 * Paste several documents together.
 * Print several pages on one sheet.
 * 1, 2, 4, 8 pages per sheet
 * Booklet. Folding the sheets in two, you’ll get a book.

%prep
%setup -q

%build
%cmake_qt5
%make_build

%install
%make_install -C build

%__mkdir -p %{buildroot}%{_datadir}/%{name}/scripts
%__install -m 755 scripts/installPrinter.sh %{buildroot}%{_datadir}/%{name}/scripts/
chmod +x %{buildroot}%{_datadir}/%{name}/scripts/installPrinter.sh
mkdir -p %{buildroot}/%{_localstatedir}/cache/%{name}

# Add translation lang tags
(cd %{buildroot} && find . -name '*.qm') | %__sed -e 's|^.||' | sed -e \
    's:\(.*/translations/boomaga_\)\([a-z_A-Z]\+\)\(.*qm$\):%lang(\2) \1\2\3:'\
        >> %{name}.lang

%pre
# Start cups if is stopped
if [ "$(systemctl is-active cups.service)" != "active" ]; then
    systemctl start cups
    sleep 2
fi

%post
# Install the printer to cups backends
if [ $1 = 1 ]; then
    sh %{_datadir}/%{name}/scripts/installPrinter.sh
fi

%preun
# Uninstall the printer
lpadmin -x "Boomaga"

%files -f %{name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/scripts
%{_bindir}/%{name}
%attr(700,root,root) %{_prefix}/lib/cups/backend/%{name}
%dir %{_localstatedir}/cache/%{name}
%{_libdir}/%{name}/
%{_datadir}/dbus-1/services/org.%{name}.service
%{_mandir}/man1/%{name}.1.xz
%{_datadir}/ppd/%{name}/
%{_datadir}/%{name}/scripts/installPrinter.sh
%{_datadir}/applications/boomaga.desktop
%{_iconsdir}/hicolor/*/apps/boomaga.png
%{_datadir}/mime/packages/boomaga.xml


%changelog
* Sun Aug 19 2018 dglent <dglent> 1.3.0-1.mga6
  (not released yet)
+ Revision: 1252741
- Version 1.3.0
- Fixes mga#23461 (fails to open file)

* Thu Jan 26 2017 luigiwalser <luigiwalser> 0.7.1-11.mga6
+ Revision: 1083458
- use 700 perms for cups backend so it will execute as root (from fedora)
- also package /var/cache/boomaga directory (from fedora)

* Mon Jan 02 2017 luigiwalser <luigiwalser> 0.7.1-10.mga6
+ Revision: 1079504
- rebuild for poppler

* Mon Nov 28 2016 luigiwalser <luigiwalser> 0.7.1-9.mga6
+ Revision: 1070608
- rebuild for poppler

* Sat Aug 13 2016 luigiwalser <luigiwalser> 0.7.1-8.mga6
+ Revision: 1046168
- test rebuild for poppler

* Wed May 25 2016 luigiwalser <luigiwalser> 0.7.1-7.mga6
+ Revision: 1018534
- rebuild for poppler

* Mon May 09 2016 luigiwalser <luigiwalser> 0.7.1-6.mga6
+ Revision: 1011745
- rebuild for poppler

* Fri Jan 01 2016 luigiwalser <luigiwalser> 0.7.1-5.mga6
+ Revision: 917799
- rebuild for poppler

* Tue Sep 01 2015 cjw <cjw> 0.7.1-4.mga6
+ Revision: 871951
- rebuild with gcc 5

* Sat Jul 25 2015 tv <tv> 0.7.1-3.mga6
+ Revision: 857589
- rebuild for new poppler

* Sat Jul 25 2015 tv <tv> 0.7.1-2.mga6
+ Revision: 857574
- rebuild for new poppler

* Fri Jun 26 2015 dglent <dglent> 0.7.1-1.mga6
+ Revision: 844279
- Version 0.7.1

* Fri Jun 26 2015 sander85 <sander85> 0.7.0-2.mga6
+ Revision: 844235
- Rebuild for new poppler

* Sun Jun 21 2015 dglent <dglent> 0.7.0-1.mga6
+ Revision: 837625
- New version 0.7.0
  Qt5 build

* Wed Oct 15 2014 umeabot <umeabot> 0.6.0-3.mga5
+ Revision: 739733
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.6.0-2.mga5
+ Revision: 678200
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 dglent <dglent> 0.6.0-1.mga5
+ Revision: 670402
- New version 0.6.0

* Thu May 01 2014 luigiwalser <luigiwalser> 0.5.0-2.mga5
+ Revision: 619132
- rebuild for poppler

* Mon Mar 31 2014 dglent <dglent> 0.5.0-1.mga5
+ Revision: 610985
- New version 0.5.0

* Sun Feb 23 2014 dglent <dglent> 0.4.0-1.mga5
+ Revision: 595863
- New version 0.4.0

* Sun Jan 05 2014 dglent <dglent> 0.3.0-2.mga5
+ Revision: 564711
- Search for translations and add them tags

* Sun Dec 15 2013 dglent <dglent> 0.3.0-1.mga4
+ Revision: 556923
- Change the URL ans Source to the project's site
- Add tags for the double licensing
- Remove br cups-filters (integrated in package)
- New version 0.3.0
- Add poppler and poppler-qt4 in br
- Install with exec permissions the script in %%post
- Add lang pl_PL
- Run cups service before installation
- Add %%dir in %%files
- Add Requires(pre) for ghostscript and task-printing-server (for cups service)
- Add Requires cups-filters for pstopdf
- Add %%mandir tag
- Add 2 more translations with tag
- Remove arch from br
- Add cups-common in Requires(preun): %%preun before uninstall
- Add Requires(post): paper-utils (part of the install script)
- Add lang tags
- Update spec file
- imported package boomaga

